@@ -2,9 +2,12 @@
 import os
 import sys
 import json
+import shutil
 
 from datetime import datetime
 
+import gtkme
+
 from . import __version__, __inkscape__
 
 filters = ['.pyc', '.swp', '~', 'package.json']
@@ -23,10 +26,19 @@ elif '-p' in sys.argv and sys.argv[-1].endswith('.json'):
         'manage_extensions.inx',
         'manage_extensions.py',
     ]
-    for (base, dirs, files) in os.walk('inkman'):
+
+    if not os.path.isdir('gtkme'):
+        os.makedirs('gtkme')
+
+    for (base, dirs, files) in os.walk(os.path.dirname(gtkme.__file__)):
         for filename in files:
-            if not any([flt for flt in filters if filename.endswith(flt)]):
-                pkg["files"].append(os.path.join(base, filename))
+            shutil.copy(os.path.join(base, filename), os.path.join('gtkme', filename))
+
+    for module in ('inkman', 'gtkme'):
+        for (base, dirs, files) in os.walk(module):
+            for filename in files:
+                if not any([flt for flt in filters if filename.endswith(flt)]):
+                    pkg["files"].append(os.path.join(base, filename))
 
     print(sys.argv[-1])
     for item in pkg["files"]:
